==> kboincspy_0.9.0.orig.tar.gz: kboincspy-0.9.0.orig/src/monitors/predictor/kbspredictorpreferences.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Roberto Virga                                   *
 *   rvirga@users.sf.net                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef KBSPREDICTORPREFERENCES_H
#define KBSPREDICTORPREFERENCES_H

#include <kconfigskeleton.h>

#include <kbspredictormoleculelog.h>

class KBSPredictorPreferences : public KConfigSkeleton
{
  public:
    KBSPredictorPreferences();
    
    virtual KBSPredictorMoleculeLogPreferences moleculeLogPreferences(PredictorAppType type);
    
  public:
    int filter[2], format[2], style[2], coloring[2];
    QString location[2];
};

#endif

==> kboincspy_0.9.1.orig.tar.gz: kboincspy-0.9.1.orig/src/monitors/predictor/kbspredictorpreferences.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Roberto Virga                                   *
 *   rvirga@users.sourceforge.net                                          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef KBSPREDICTORPREFERENCES_H
#define KBSPREDICTORPREFERENCES_H

#include <kconfigskeleton.h>

#include <kbspredictormoleculelog.h>

class KBSPredictorPreferences : public KConfigSkeleton
{
  public:
    KBSPredictorPreferences();
    
    virtual KBSPredictorMoleculeLogPreferences moleculeLogPreferences(KBSPredictorAppType type);
    
  public:
    int filter[2], format[2], style[2], coloring[2];
    QString location[2];
};

#endif
